==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>افزونه %1 با سیستم سازگار نیست.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>تنظیمات بلوتوث</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>خاموش کردن</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>روشن کردن</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>تنظیمات بلوتوث</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>بلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>بلوتوث</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>اضافه کردن طرح بندی صفحه کلید</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>تاریخ زمان</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>زمان 12-ساعته</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>زمان 24-ساعته</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>تنظیمات زمان</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>غیر فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تنظیمات شبکه</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>آیا مطمئن هستید که می خواهید %1 موارد را خالی کنید؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>این عملیات قابل بازگردانی نیست</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>دستگاه ناشناخته</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>حجم ناشناخته</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دیسک</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>باز کردن</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>خارج کردن همه</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>لانچر</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>حالت فشن</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>حالت کارآمد</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>بالا</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>پایین</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>نمایش داده شود</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>مخفی نگاه داشتن</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>مخفی سازی هوشمند</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>حالت</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>مکان</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>وضعیت </translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>پلاگین ها</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>نمای چند وظیفه ای</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>باز کردن از داک</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable network</source>
        <translation>غیر فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تنظیمات شبکه</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>دستگاه غیرفعال است</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>اتصال سیمی %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>متصل نیست</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>در حال اتصال</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>متصل است اما دسترسی به اینترنت ندارد</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>کابل شبکه وصل نشده است</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>شبکه سیمی %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>روی صفحه</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تنظیمات</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>منبع قدرت</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>تنظیمات برق</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ظرفیت %1, %2 دقیقه باقی مانده است</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ظرفیت %1 ،%2 ساعت  %3 دقیقه باقی مانده است</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>درحال شارژ %1 ، %2 دقیقه تا شارژ کامل</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>درحال شارژ %1 ، %2 ساعت و  %3 دقیقه تا شارژ کامل</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>نمایش دسکتاپ</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>باز کردن از داک</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>منبع قدرت</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>خارج شدن از حساب کاربری</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>تعویض حساب کاربری</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>تنظیمات برق</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>دستگاه</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>باصدا</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>بی صدا</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>تنظیمات صدا</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>صدا</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>سطل زباله</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>سطل زباله - %1 فایل</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>سطل زباله - %1 فایل</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>باز کردن</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>خالی</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>سینی سیستم</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>شبکه بی سیم %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.67.orig.tar.xz: dde-dock-5.5.67/translations/dde-dock_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>افزونه %1 با سیستم سازگار نیست.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>تنظیمات بلوتوث</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>خاموش کردن</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>روشن کردن</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>تنظیمات بلوتوث</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>بلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>بلوتوث</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>اضافه کردن طرح بندی صفحه کلید</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>تاریخ زمان</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>زمان 12-ساعته</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>زمان 24-ساعته</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>تنظیمات زمان</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>آیا مطمئن هستید که می خواهید %1 موارد را خالی کنید؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>این عملیات قابل بازگردانی نیست</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>دستگاه ناشناخته</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>حجم ناشناخته</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دیسک</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>باز کردن</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>خارج کردن همه</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>لانچر</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>حالت فشن</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>حالت کارآمد</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>بالا</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>پایین</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>نمایش داده شود</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>مخفی نگاه داشتن</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>مخفی سازی هوشمند</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>حالت</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>مکان</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>وضعیت </translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>پلاگین ها</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>نمای چند وظیفه ای</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>باز کردن از داک</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>روی صفحه</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تنظیمات</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>منبع قدرت</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>تنظیمات برق</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ظرفیت %1, %2 دقیقه باقی مانده است</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ظرفیت %1 ،%2 ساعت  %3 دقیقه باقی مانده است</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>درحال شارژ %1 ، %2 دقیقه تا شارژ کامل</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>درحال شارژ %1 ، %2 ساعت و  %3 دقیقه تا شارژ کامل</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>نمایش دسکتاپ</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>باز کردن از داک</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>منبع قدرت</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>خارج شدن از حساب کاربری</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>تعویض حساب کاربری</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>تنظیمات برق</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>دستگاه</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>باصدا</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>بی صدا</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>تنظیمات صدا</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>صدا</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>سطل زباله</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>سطل زباله - %1 فایل</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>سطل زباله - %1 فایل</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>باز کردن</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>خالی</translation>
    </message>
</context>
</TS>
